@@ -2,6 +2,7 @@
 import argparse
 from glob import glob
 import random
+import time
 import os.path
 from contextlib import contextmanager
 
@@ -13,6 +14,7 @@ def cd(path):
   os.chdir(old_dir)
 
 _dir = os.path.dirname(os.path.abspath(__file__))
+secure_random = random.SystemRandom(time.time)
 
 def available_languages():
   with cd(_dir + "/dictionaries/"):
@@ -21,7 +23,7 @@ def available_languages():
 
 def generate(lang, num):
   try:
-    return [x.strip() for x in sorted(random.sample(list(open('%s/dictionaries/%s.txt' % (_dir, lang))), num))]
+    return [x.strip() for x in sorted(secure_random.sample(list(open('%s/dictionaries/%s.txt' % (_dir, lang))), num))]
   except:
     return ["Dictionary ", lang, " not found. Use the '-L' flag to list available dictionaries."]
 
